@@ -2,6 +2,7 @@ from irc.bot import SingleServerIRCBot
 from irc.client import ServerConnection, Event
 
 from .commands import COMMANDS
+from .events import EVENTS
 from .models import TwitchTags
 
 
@@ -26,6 +27,7 @@ class BitBitBot(SingleServerIRCBot):
         conn.cap('REQ', ':twitch.tv/tags')
         conn.cap('REQ', ':twitch.tv/commands')
         conn.join(self.channel)
+        print('Bot is live')
 
     def on_pubmsg(self, conn: ServerConnection, event: Event):
         msg = event.arguments[0]
@@ -38,5 +40,17 @@ class BitBitBot(SingleServerIRCBot):
             if command in COMMANDS:
                 COMMANDS[command](self, ' '.join(parts), tags)
 
+        self.emit_event(
+            'chat_message',
+            {
+                'msg': msg,
+                'tags': TwitchTags,
+            }
+        )
+
     def send_message(self, message: str) -> None:
         self.connection.privmsg(self.channel, message)
+
+    def emit_event(self, event_name: str, event_data) -> None:
+        for listener in EVENTS[event_name]:
+            listener(event_data)
